# cli.py
import click
from crt.option import crt_files, crt_temp


@click.command()
@click.option('-t',
              '--temp',
              required=False,
              type=str,
              help='main:config:setup',)
@click.argument('oth', required=False,)
@click.argument('ext', required=False,)
def main(temp, oth, ext):
    """
files: \tTo create files use 'crt' and list the names in quotes to list use the ':' sign to create folders use brackets after the name '<','>' in brackets you can specify files, after all names indicate file extensions if not specified in the names.
Example: crt "file_name1:file_name2:dir_name1<>:dir_name2<file_name>" py\n
temp: \tTo create a project use '-t' or '--temp' and specify the name of the template, by default there are the following templates: 'web-front', 'web-back', 'app', 'project', 'config'.
Example: crt -t app"""
    if temp:
        crt_temp(temp)
    else:
        crt_files(ext, oth)


if __name__ == '__main__':
    main()



import json
import pkg_resources


def get_templates(name: str):
    try:
        template_path = pkg_resources.resource_filename(
            __name__, 'data/templates.json')
        with open(template_path, 'r', encoding='utf-8') as json_file:
            temp_file: dict = json.load(json_file)
        if (name in temp_file):
            return temp_file.get(name)
        return None
    except FileNotFoundError:
        print("JSON file not found.")
        return None
    except json.JSONDecodeError:
        print("Error reading JSON file.")
        return None



import unittest
from click.testing import CliRunner
from crt.cli import main


class TestMain(unittest.TestCase):
    def test_main(self):
        runner = CliRunner()
        result = runner.invoke(main, ["-n", "sd", "asd.py"])

        self.assertEqual(result.exit_code, 0)


if __name__ == '__main__':
    unittest.main()



import os
from crt.templates import get_templates
from crt.tools import get_all_directories, get_file_nesting, is_correct_request


def c_f(t_str_names,  ext=None, name=None):
    if type(t_str_names) is dict:
        for key in t_str_names:
            if (name):
                full_name = name+"\\"+key
                if not os.path.isdir(full_name):
                    os.system(f"mkdir {full_name}")
            else:
                full_name = key
                if not os.path.isdir(full_name):
                    os.system(f"mkdir {full_name}")
            for file in t_str_names[key]:
                if type(file) is str:
                    if full_name and file:
                        file_name = f"{full_name}\{file}.{ext}" if ext else f"{full_name}\{file}"
                    elif file:
                        file_name = f"{file}.{ext}" if ext else f"{file}"
                    else:
                        file_name = None
                    if file_name:
                        if not os.path.isfile(file_name):
                            os.system(f"type NUL > {file_name}")
                else:
                    c_f(t_str_names=file,  ext=ext, name=full_name)
    else:
        for file in t_str_names:
            if (name):
                if not os.path.isdir(name):
                    os.system(f"mkdir {full_name}")
                full_name = name+'\\'
            else:
                full_name = ""
            if type(file) is str:
                if (full_name):
                    file_name = f"{full_name}\{file}.{ext}" if ext else f"{full_name}\{file}"
                else:
                    file_name = f"{file}.{ext}" if ext else f"{file}"
                if not os.path.isfile(file_name):
                    os.system(f"type NUL > {file_name}")
            else:
                c_f(file, ext, full_name)


def c_d(l_str_names):
    if type(l_str_names) is dict:
        for key in l_str_names.keys():
            l_str_names[key] = c_d(l_str_names[key])
    else:
        for index in range(len(l_str_names)):
            if type(l_str_names[index]) is dict:
                l_str_names[index] = c_d(l_str_names[index])
            else:
                if not '.' in l_str_names[index] and l_str_names[index] != "LICENSE":
                    l_str_names[index] = {l_str_names[index]: []}
    return l_str_names


def crt_files(ext, t_str_names):
    ans = is_correct_request(t_str_names)
    if ans == 1:
        l_dir = get_file_nesting(t_str_names, len(t_str_names))
        c_f(l_dir, ext)
    elif ans == '>' or ans == '<':
        print(f"missing sign '{ans}' (use crt --help)")
    else:
        print(f"{ans} (use crt --help)")


def crt_dirs(t_str_names):
    all_directories = get_all_directories('.')
    for str_names in t_str_names:
        for dir_name in str_names.split(":"):
            if dir_name not in all_directories:
                os.system(f"mkdir {dir_name}")


def crt_temp(temp_name):
    l_temp = get_templates(temp_name)
    if l_temp:
        l_dir = c_d(l_temp)
        c_f(l_dir)
    else:
        print(
            f"no such template name '{temp_name}'\nby default there are the following templates: 'web-front', 'web-back', 'app', 'project', 'config'")



import os


def get_all_directories(path) -> list:
    files = os.listdir(path)
    return files


def get_file_nesting(nest, size_n) -> list:
    s_name = 0
    index = 0
    l_dir = []

    while index < len(nest):
        if nest[index] == '<':
            if nest[index+1] == '>':
                t_dir = ([], 1)
            else:
                t_dir = get_file_nesting(nest[index+1:], size_n)
            if type(t_dir) is tuple:
                list_dir, ind = t_dir
            else:
                list_dir = t_dir
                ind = size_n - index
            l_dir.append({f"{nest[s_name:index].replace(':', '')}": list_dir})
            index = index+ind + 1
            s_name = index+ind + 1
        if index+1 == len(nest):
            if (nest[s_name:index]):
                if (nest[index] == '>'):
                    l_dir.append(nest[s_name:index].replace(':', ''))
                else:
                    l_dir.append(nest[s_name:index+1].replace(':', ''))
                if index + 1 >= size_n:
                    return l_dir
                return (l_dir, index)
            return (l_dir)
        if index+1 > len(nest):
            if (nest[s_name:index]):
                l_dir.append(nest[s_name:index].replace(':', ''))
                if index + 1 >= size_n:
                    return l_dir
                return (l_dir, index)
            return (l_dir)
        if nest[index] == ':':
            if nest[s_name:index]:
                l_dir.append(nest[s_name:index].replace(':', ''))
            s_name = index
        if nest[index] == '>':
            if nest[s_name:index]:
                l_dir.append(nest[s_name:index].replace(':', ''))
            return (l_dir, index+1)
        index += 1
    return l_dir


def is_correct_request(s_name: str):

    incor_symbols = ['"', '|', '?', '*', ';', "'", ' ',]

    for sym in s_name:
        if sym in incor_symbols:
            return f"don't use signs {sym} in names"

    cont_l_b = s_name.count('<')
    cont_r_b = s_name.count('>')
    if cont_l_b == cont_r_b:
        return 1
    if cont_l_b < cont_r_b:
        return '<'
    if cont_l_b > cont_r_b:
        return '>'



# setup.py
from setuptools import setup, find_packages
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

NAME = "crtfiles"
setup(
    name=NAME,
    version='1.1.6',
    author="feed619",
    author_email="azimovpro@gmail.com",
    description="create files quickly and conveniently with the 'crt' utility",
    long_description=long_description,
    long_description_content_type='text/markdown',
    url="https://github.com/feed619/crtfiles",
    packages=find_packages(),
    install_requires=[
        'click',
    ],
    entry_points={
        'console_scripts': [
            'crt=crt.cli:main',
        ],
    },
    license='MIT',
    include_package_data=True,
    package_data={
        'crt': ['data/templates.json'],
    },
    classifiers=[
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
    ],
    python_requires='>=3.7',
)
